package FieldBlock::Plugin;
use strict;

use lib qw( addons/CustomObject.pack/lib addons/PowerCMS.pack/lib );
use CustomObject::Plugin;
use CustomObject::Listing;
use PowerCMS::Util qw( utf8_on build_tmpl );

sub system_filters_tag {
    return {
        fieldblock => {
            label => 'Tags with FieldBlock',
            view  => [ 'blog', 'website' ],
            items => [ { type => 'for_fieldblock' } ],
            order => 1001,
        },
    };
}

sub list_props_tag {
    return {
        for_fieldblock => {
            base        => 'tag.for_customobject',
            label       => 'Tags with FieldBlock',
            obj_class   => 'fieldblock',
        },
        fieldblock_count => {
            label       => 'FieldBlock',
            base        => 'tag.customobject_count',
            count_class => 'customobject',
            display     => 'default',
            order       => 1000,
            obj_class   => 'fieldblock',
        },
    };
}

sub system_filters_group {
    my $plugin = MT->component( 'FieldBlock' );
    my $filters = {
        my_posts => {
            label => $plugin->translate( 'My FieldBlock Groups' ),
            items => sub {
                [ { type => 'current_user' } ];
            },
            order => 1000,
        },
    };
    return $filters;
}

sub system_filters_fieldblock {
    return CustomObject::Listing::system_filters_customobject( 'meth', 'fieldblock' );
}

sub list_props {
    return CustomObject::Listing::list_props( 'meth', 'fieldblock' );
}

sub list_group_props {
    return CustomObject::Listing::list_group_props( 'meth', 'fieldblock' );
}

sub list_actions {
    return CustomObject::Listing::list_actions( 'meth', 'fieldblock' );
}

sub list_group_actions {
    return CustomObject::Listing::list_group_actions( 'meth', 'fieldblock' );
}

sub content_actions {
    return CustomObject::Listing::content_actions( 'meth', 'fieldblock' );
}

sub _menu_permission {
    return CustomObject::Plugin::_menu_permission( 'meth', 'fieldblock' );
}

sub _group_menu_permission {
    return CustomObject::Plugin::_group_menu_permission( 'meth', 'fieldblock' );
}
sub _customfield_types {
    require CustomObject::Field;
    return CustomObject::Field::_customfield_types( 'meth', 'fieldblock', 'FieldBlock', 2024 );
}

sub _view_log {
    my ( $cb, $app, $param, $tmpl ) = @_;
    my $plugin = 'fieldblock';
    my ( $label_en, $label_ja, $label_plural ) = CustomObject::Plugin::__get_settings( $app, $app->blog, $plugin );
    my $class_loop = $param->{ class_loop };
    push @$class_loop, { class_name => 'fieldblock', class_label => $label_ja };
    $param->{ class_loop } = $class_loop;
}

sub _pre_run {
    my ( $cb, $app ) = @_;
    if ( $app->param( 'search_result' ) ) {
        if ( my $blog_id = $app->param( 'blog_id' ) ) {
            if ( my $id = $app->param( 'id' ) ) {
                if ( $app->param( '_type' ) &&
                     $app->param( '_type' ) eq 'fieldblock' ) {
                     $app->redirect( $app->base . $app->uri( mode => 'view',
                                            args => { blog_id => $blog_id,
                                                      _type => 'customobject',
                                                      class => 'fieldblock',
                                                      id => $id } ) );
                }
            }
        }
    }
    my $plugin = 'fieldblock';
    my $orig_ja = utf8_on( 'フィールドブロック' );
    my $orig_en = utf8_on( 'FieldBlock' );
    my $orig_plural = utf8_on( 'FieldBlocks' );
    my $orig_en_lc = lc( $orig_en );
    my $map = {
        'CustomObject'  => 'フィールドブロック',
        'CustomObjects' => 'フィールドブロック',
        'CustomObject Group' => 'フィールドブロックグループ',
        'CustomObject Groups' => 'フィールドブロックグループ',
        'Folder-FieldBlock' => 'フォルダ別フィールドブロック',
        'FieldBlock' => 'フィールドブロック',
        'FieldBlocks' => 'フィールドブロック',
        'Manage FieldBlock' => 'フィールドブロックの管理',
        'Manage FieldBlock Groups' => 'フィールドブロックグループの管理',
        'Multiple FieldBlock' => 'フィールドブロック(複数選択)',
        'My FieldBlock' => '自分のフィールドブロック',
        'My FieldBlocks' => '自分のフィールドブロック',
        'My FieldBlock Groups' => '自分のフィールドブロックグループ',
        'Tags with FieldBlock' => 'フィールドブロックのタグ',
        'FieldBlock Group' => 'フィールドブロックグループ',
        'FieldBlock Groups' => 'フィールドブロックグループ',
        'Create and manage fieldblock.' => 'フィールドブロックを作成・管理します。',
        'Create and Manage FieldBlock.' => 'フィールドブロックの作成・管理をします。',
        'Save this FieldBlock' => 'このフィールドブロックを保存する',
        'Save this FieldBlock (s)' => 'このフィールドブロックを保存する (s)',
        'Publish this FieldBlock' => 'このフィールドブロックを公開する',
        'Publish this FieldBlock (s)' => 'このフィールドブロックを公開する (s)',
        'Re-Edit this FieldBlock' => 'このフィールドブロックを編集する',
        'Re-Edit this FieldBlock (e)' => 'このフィールドブロックを編集する (e)',
        'You are previewing the FieldBlock entitled &ldquo;[_1]&rdquo;' => 'プレビュー中: フィールドブロック「[_1]」',
        'Cloning FieldBlock Groups for blog...' => 'フィールドブロックグループを複製しています...',
        'Cloning FieldBlocks for blog...' => 'フィールドブロックを複製しています...',
        'Cloning FieldBlock tags for blog...' => 'フィールドブロックのタグを複製しています...',
        'Exclude FieldBlocks' => 'フィールドブロックの除外',
    };
    my $lh = MT->language_handle;
    my $package = ref $lh;
    require CustomObject::Plugin;
    my ( $label_en, $label_ja, $label_plural ) = CustomObject::Plugin::__get_settings( $app, $app->blog, $plugin );
    $label_ja = utf8_on( 'フィールドブロック' ) unless $label_ja;
    my $search_ja = utf8_on( 'フィールドブロック' );
    my $search_en = 'FieldBlock';
    my $search_plural = 'FieldBlocks';
    my $search_lc = 'fieldblock';
    my $label_lc = lc( $label_en );
    for my $key ( keys( %$map ) ) {
        my $text = utf8_on( $map->{ $key } );
        $map->{ $key } = $text;
        if ( $package eq 'MT::L10N::ja' ) {
            $text =~ s/\Q$search_ja\E/$label_ja/;
            # $text =~ s/$orig_ja/$label_ja/;
            $map->{ $key } = $text;
        } else {
            my $new = $key;
            $new =~ s/$search_en/$label_en/;
            $new =~ s/$search_plural/$label_plural/;
            $new =~ s/$search_lc/$label_lc/;
            $new =~ s/$search_lc/$label_lc/;
            # $new =~ s/$orig_en/$label_en/;
            # $new =~ s/$orig_en_lc/$label_lc/;
            $map->{ $key } = $new;
        }
    }
    if ( $package eq 'MT::L10N::ja' ) {
        $map->{ $plugin } = $label_ja;
    } else {
        $map->{ $plugin } = $label_en;
    }
    $package =~ s/^MT/FieldBlock/;
    eval(<<__END__);
package $package;
\$Lexicon{\$_} = \$map->{\$_} foreach ( keys( %\$map ) );
__END__
    return 1;
}

1;
